import { Injectable, Optional } from '@angular/core';
import { User } from '../models/user.model';
import { LogService } from './log.service';
import { HttpClient } from '@angular/common/http';
import { Observable, throwError } from 'rxjs';
import { map, catchError } from 'rxjs/operators';

@Injectable()

export class UsersService {

  constructor(@Optional() private logService: LogService, private http: HttpClient) { }

  private users: User[] = [
    new User("Ben",25, 'test@test.com','pass'),
    new User("John",35, 'test@test.com','pass'),
    new User("Bob",45, 'test@test.com','pass'),
  ];


  getUsers() : Observable<User[]> {
    if(this.logService) {
      this.logService.write("Get users array");
    }
    return this.http.get<User[]>('http://ang.loc/api/users').pipe(
      map((data) => {
        return data['users'];
      }),
      catchError(err => {  
        console.log('error',err); 
        return throwError(err);
      })
    )
    
  }

  getUser(nmb: number): User {
    return this.users[nmb];
  }

  createUser(user: User):  Observable<User> {
    return this.http.post<User>('http://ang.loc/api/users', user).pipe(
      map((data) => {
        return data['user'];
      }),
      catchError(err => {  
        console.log('error',err); 
        return throwError(err);
      })
    )
  }

  updateUser(user: User, name : string) {
    return this.http.put<User>('http://ang.loc/api/users/'+user.id, {name : name}).pipe(
      map((data) => {
        return data['user'];
      }),
      catchError(err => {  
        console.log('error',err); 
        return throwError(err);
      })
    )
  }

  destroyUser(user) {
    return this.http.delete('http://ang.loc/api/users/'+user.id, user).pipe(
      catchError(err => {  
        console.log('error',err); 
        return throwError(err);
      })
    )
  }

   
}
