import { Component, OnInit, ViewChild, ElementRef } from '@angular/core';
import { User } from '../models/user.model';
import { UserComponent } from '../user/user.component';
import { UserFormComponent } from '../user-form/user-form.component';
import { UsersService } from '../services/users.service';
import { LogService } from '../services/log.service';
import { ComponentCanDeactivate } from '../guards/exitUsers.guard';
import { Observable } from 'rxjs';
import { HttpClient } from '@angular/common/http';

@Component({
  selector: 'app-users',
  templateUrl: './users.component.html',
  styleUrls: ['./users.component.sass']
})
export class UsersComponent implements OnInit {

  title: string = "Список пользователей";
  user: User;

  users: User[] = [];



  isFilterAge: boolean = false;
  searchName: string = "";

  constructor(private userService: UsersService, private http: HttpClient) { 
    
  }
  
  
  ngOnInit(): void {
    //this.users = this.userService.getUsers();
    
    // this.http.get('http://ang.loc/api/users').subscribe((response: User[]) => {
    //   this.users = response
    // })

    this.userService.getUsers().subscribe((response: User[]) => {
      this.users = response
    },error => {console.log(error);})
  }

  onUserAdded($user: User) {
    this.user = $user;
    this.userService.createUser($user).subscribe((response: User) => {
      this.users.push(response)
    },error => {console.log(error);})
  }

  onUserEditted(data: {user:User, name:string}) {
  
    
    this.userService.updateUser(data.user, data.name).subscribe((response: User) => {
      let index = this.users.indexOf(data.user);
      this.users[index] = response;
    },error => {console.log(error);})
  }
  onUserDeleted($user: User) {
    this.user = $user;
    this.userService.destroyUser($user).subscribe(() => {
      this.users = this.users.filter(user => $user.id !== user.id)
    },error => {console.log(error);})
  }

}
